package org.jvending.provisioning.adapter;

import junit.framework.TestCase;

import javax.provisioning.adapter.AdapterException;
import javax.provisioning.adapter.AdapterContext;
import javax.provisioning.adapter.AdapterConfig;
import javax.provisioning.BundleRepository;
import javax.provisioning.BundleDescriptor;
import javax.provisioning.DescriptorFile;
import javax.provisioning.FulfillmentTask;
import javax.servlet.ServletContext;

import org.easymock.MockControl;

import java.net.URL;
import java.net.MalformedURLException;

public class MidpAdapterTest extends TestCase {

    private MidpAdapter midpAdapter;

    public void setUp() {
        MockControl controlAdapterContext = MockControl.createControl(AdapterContext.class);
        MockControl controlBundleRepository = MockControl.createControl(BundleRepository.class);
        MockControl controlBundleDescriptor = MockControl.createControl(BundleDescriptor.class);
        MockControl controlAdapterConfig = MockControl.createControl(AdapterConfig.class);
        MockControl controlFulfillmentTask = MockControl.createControl(FulfillmentTask.class);
        MockControl controlServletContext = MockControl.createControl(ServletContext.class);

        //ServletContext
        ServletContext servletContext = (ServletContext) controlServletContext.getMock();
        servletContext.getInitParameter("CONTENT_DELIVERY_URI");
        controlServletContext.setReturnValue("http://localhost:8080/provisioning");

        //BundleDescriptor
        BundleDescriptor bundleDescriptor = (BundleDescriptor) controlBundleDescriptor.getMock();
        bundleDescriptor.getDescriptorFile();
        controlBundleDescriptor.setReturnValue(new MockDescriptorFile(null, null));

        //BundleRepository
        BundleRepository bundleRepository = (BundleRepository) controlBundleRepository.getMock();
        bundleRepository.getBundleByID("123");
        controlBundleRepository.setReturnValue(bundleDescriptor);
        bundleRepository.getBundleByID("234");
        controlBundleRepository.setReturnValue(null);

        //AdapterContext
        AdapterContext adapterContext = (AdapterContext) controlAdapterContext.getMock();
        adapterContext.getBundleRepository();
        controlAdapterContext.setReturnValue(bundleRepository);
        adapterContext.getServletContext();
        controlAdapterContext.setReturnValue(servletContext);

        FulfillmentTask fulfillmentTask = (FulfillmentTask) controlFulfillmentTask.getMock();
        fulfillmentTask.getBundleDescriptor();
        controlFulfillmentTask.setReturnValue(bundleDescriptor);

        try {
            adapterContext.getFulfillmentTask("123", null, "midp");
            controlAdapterContext.setReturnValue(fulfillmentTask);
        } catch (AdapterException e) { }

        //AdapterConfig
        AdapterConfig adapterConfig = (AdapterConfig) controlAdapterConfig.getMock();
        adapterConfig.getAdapterContext();
        controlAdapterConfig.setReturnValue(adapterContext);
        adapterConfig.getAdapterContext();
        controlAdapterConfig.setReturnValue(adapterContext);

        adapterConfig.getBaseURI();
        controlAdapterConfig.setReturnValue("http://localhost:8080/jvending");

        adapterConfig.getInitParameter("install-notify");
        controlAdapterConfig.setReturnValue("true");

        adapterConfig.getInitParameter("delete-notify");
        controlAdapterConfig.setReturnValue("true");

        midpAdapter = new MidpAdapter();
        midpAdapter.setAdapterConfig(adapterConfig);

        controlAdapterContext.replay();
        controlBundleRepository.replay();
        controlBundleDescriptor.replay();
        controlAdapterConfig.replay();
        controlFulfillmentTask.replay();
        controlServletContext.replay();
    }

    public void testNullUrl() {

        //MidpAdapterProxy midpAdapter = new MidpAdapterProxy();
        try {
            midpAdapter.createDescriptorFile(null);
        } catch (AdapterException e) {

        } catch(Exception e) {
            fail("Unhandled exception when trying to create a DescriptorFile with a null URL");
        }
    }

/*
    public void testA() {
        URL url = null;
        try {
            url = new URL("http://localhost:8080/jvending?fid=123");
        } catch(MalformedURLException e) {
            fail("Improper URL in the test");
        }

        try {
            DescriptorFile descriptorFile = midpAdapter.createDescriptorFile(url);
            assertNotNull("Returned a null DescriptorFile", descriptorFile);
        } catch (AdapterException e) {
            e.printStackTrace();
            fail("Could not create descriptor file");
        }
    }
/*
    public void testMissingFulfillmentId() {
        URL url = null;
        try {
            url = new URL("http://localhost:8080/jvending");
        } catch(MalformedURLException e) {
            fail("Improper URL in the test");
        }

        try {
            midpAdapter.createDescriptorFile(url);
            fail("The URL is missing a bundleId param. Should have thrown an AdapterException.");
        } catch (AdapterException e) {

        }
    }

    public void testFulfillmentIdAsSecondParam() {
        URL url = null;
        try {
            url = new URL("http://localhost:8080/jvending?bogus=2&fid=123");
        } catch(MalformedURLException e) {
            fail("Improper URL in the test");
        }

        try {
            DescriptorFile descriptorFile = midpAdapter.createDescriptorFile(url);
            assertNotNull("Returned a null DescriptorFile", descriptorFile);
        } catch (AdapterException e) {
            e.printStackTrace();
            fail("Could not create descriptor file");
        }
    }

    public void testFulfillmentTaskThatDoesNotExist() {
        URL url = null;
        try {
            url = new URL("http://localhost:8080/jvending?bogus=2&fid=234");
        } catch(MalformedURLException e) {
            fail("Improper URL in the test");
        }

        try {
            DescriptorFile descriptorFile = midpAdapter.createDescriptorFile(url);
            assertNull("Returned a DescriptorFile for when none exists", descriptorFile);
        } catch (AdapterException e) {
            
        }
    }
*/
}
