package org.jvending.provisioning.config;

import junit.framework.TestCase;
import org.jvending.registry.RepositoryRegistry;

import javax.provisioning.Capabilities;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import java.util.List;

public class DeviceRepositoryTest extends BaseConfig {

    private DeviceRepository deviceRepository;

    public void setUp() {
        super.setUp();
        deviceRepository = (DeviceRepository) repositoryRegistry.find("devices");
        assertNotNull("Device repository is null", deviceRepository);
    }

    public void testDeviceIds() {
        Set ids = deviceRepository.getDeviceIds();
        assertEquals("Incorrect number of device ids", 9, ids.size());
    }

    public void testDeviceId() {
        Map headers = new HashMap();
        headers.put("user-agent", "SEC-SGHX105-blah-blah");
        String id = deviceRepository.getDeviceId(headers);
        assertEquals("Did not match device id", "SamsungX105", id);
    }

    public void testCapabilities() {
        Map headers = new HashMap();
        headers.put("user-agent", "MOT-V300/abc");
        Capabilities capabilities = deviceRepository.getCapabilities(headers);
        Set names = capabilities.getCapabilityNames();
        assertEquals("Incorrect number of capabilities", 3, names.size());
        assertTrue("Does not contain expected capability", names.contains("SoftwarePlatform.JavaPlatform"));
    }

    public void testAdapterNames() {
        List adapterNames = deviceRepository.getAdapterNamesFor("Nokia3650");
        System.out.println(adapterNames);
        assertEquals("Wrong number of adapters", 2, adapterNames.size());
        assertTrue("Does not contain expected adapter: midp", adapterNames.contains("midp"));
        assertTrue("Does not contain expected adapter: generic", adapterNames.contains("generic"));
    }

}
