/*
 *  JVending
 *  Copyright (C) 2006  Shane Isbell
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.jvending.provisioning.dao;

import org.hibernate.SessionFactory;
import org.jvending.registry.hibernate.DataAccessObject;

import java.util.Set;
import java.util.Iterator;
import java.util.Map;
import java.io.IOException;

/**
 * Provides basic implementation of the DataAccessObject that can be extended.
 * @author Shane Isbell
 * @since 2.0.0
 */


public abstract class BaseProvisioningDAO implements DataAccessObject {

    protected Map sessionFactories;

    protected String className;

    protected String id;

    protected BaseProvisioningDAO(String className, String id) {
        this.className = className;
        this.id = id;
    }

    protected SessionFactory getSessionFactoryByName(String name) throws IOException {
        Set keys = sessionFactories.keySet();
        for(Iterator i = keys.iterator(); i.hasNext(); ){
            String n = (String) i.next();
            if(n.equals(name)) return (SessionFactory) sessionFactories.get(n);
        }
        throw new IOException("Could not find session factory: Name = " + name);
    }

    public void setSessionFactories(Map sessionFactories) {
        this.sessionFactories = sessionFactories;
    }

    public String getClassName() {
        return className;
    }

    public String getID() {
        return id;
    }

}
