/*
 *  JVending - JSP Tag Library
 *  Copyright (C) 2004  Shane Isbell
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.jvending.provisioning.taglib;

import java.io.IOException;

import java.util.Locale;
import java.util.logging.*;

import javax.provisioning.BundleDescriptor;

import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.tagext.TagSupport;

/**
 * Writes out a vendor name for the the locale of a BundleDescriptor.
 * @author Shane Isbell
 * @since 1.3.9a
 */

public class VendorNameTag extends TagSupport {
    /**Logger*/
    private static Logger logger = Logger.getLogger("VendorNameTag");

    /**
     * <code>BundleDescriptor</code>
     */
    private BundleDescriptor descriptor;
    /**
     * Locale for the vendor name.
     */
    private String locale;

    /**
     * Sets the locale for the vendor name
     * @param locale
     */
    public void setLocale(String locale) {
        this.locale = locale;
    }

    /**
     * Returns the locale that is set for this vendor name or null if none is set.
     * @return the locale that is set for this vendor name or null if none is set.
     */
    public String getLocale() {
        return locale;
    }

    public int doStartTag() throws JspTagException {
        descriptor = (BundleDescriptor)
             pageContext.getAttribute("descriptor", 
                                       pageContext.PAGE_SCOPE);
        
        return SKIP_BODY;
    }

    public int doEndTag() throws JspTagException {
        if(descriptor == null) {
            logger.finest("Descriptor is null. Not processing vendor name.");
            return EVAL_PAGE;
        }

        String vendorName = (locale != null) ? descriptor.getVendor(new Locale(locale)): 
                                               descriptor.getVendor(null);
        if(vendorName == null) vendorName = "";
        try {
            pageContext.getOut().println(vendorName);
        } catch(IOException e) {
            e.printStackTrace();
            throw new JspTagException("Could not End Tag. Vendor Name = " + vendorName + ", Locale = " + locale);
        } 
        return EVAL_PAGE;
    }
}